//+------------------------------------------------------------------+
//|                                            EasyXmlIntegrator.mq5 |
//|                                  Copyright 2013, Paul van Hemmen |
//|                                          http://www.vanhemmen.de |
//+------------------------------------------------------------------+
#property copyright "Copyright 2013, Paul van Hemmen"
#property link      "http://www.vanhemmen.de"
#property version   "1.00"

//+------------------------------------------------------------------+
//| Includes                                                         |
//+------------------------------------------------------------------+
#include <EasyXML\EasyXml.mqh>
//+------------------------------------------------------------------+
//| read xml recursive                                               |
//+------------------------------------------------------------------+
int readRecursive(CEasyXmlNode *ActualNode,int iNodeLevel=0)
  {
   // Output vars
   string sSpace;
   string sOutput;

   // Indent output for better readability
   StringInit(sSpace,iNodeLevel*4,StringGetCharacter(" ",0));

   // Concatenate output string
   sOutput += sSpace + IntegerToString(iNodeLevel) + " - Node Name: '" + ActualNode.getName() + "'";
   sOutput += (ActualNode.getValue()) ? " Value: '" + ActualNode.getValue() + "'" : "";

   // Iterate through AttributeNodes
   for(int i=0; i<ActualNode.Attributes().Total(); i++)
     {
      CEasyXmlAttribute *Attribute=ActualNode.Attributes().At(i);
      sOutput+=" || Attribute "+IntegerToString(i+1)+": '"+Attribute.getName()+"' Value: '"+Attribute.getValue()+"'";
     }

   Print(sOutput);

   // Iterate through child nodes
   for(int j=0; j<ActualNode.Children().Total(); j++)
     {
      CEasyXmlNode *ChildNode=ActualNode.Children().At(j);
      readRecursive(ChildNode,iNodeLevel+1);
     }

   return(0);
  }
//+------------------------------------------------------------------+
//| Script program start function                                    |
//+------------------------------------------------------------------+
void OnStart()
  {
   // Create instance of class CEasyXml
   CEasyXml EasyXmlDocument;

   // Optional debugging
   EasyXmlDocument.setDebugging(true);

   // Set Url Cache File
   EasyXmlDocument.setUrlCacheFile("forexcalendar.xml");

   // Method 1: Load XML from URL
   if(EasyXmlDocument.loadXmlFromUrl("http://www.forexfactory.com/ffcal_week_this.xml"))
     {
      readRecursive(EasyXmlDocument.getDocumentRoot());
     }

   // Clear the DOM
   EasyXmlDocument.Clear();

   // Method 2: Load XML from string
   if(EasyXmlDocument.loadXmlFromString("<root><child attr='value'>content</child><sibling>siblingcontent</sibling></root>"))
     {
      readRecursive(EasyXmlDocument.getDocumentRoot());
     }

   // Clear the DOM
   EasyXmlDocument.Clear();

   // Method 3: Load XML from file
   if(EasyXmlDocument.loadXmlFromFile("forexcalendar.xml"))
     {
      readRecursive(EasyXmlDocument.getDocumentRoot());
     }
  }
//+------------------------------------------------------------------+
